==> kbarcode-trinity-3.5.13.2.tar.xz: kbarcode-trinity-3.5.13.2/kbarcode/previewdialog.h <==
/***************************************************************************
                          previewdialog.h  -  description
                             -------------------
    begin                : Die Dez 10 2002
    copyright            : (C) 2002 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PREVIEWDIALOG_H
#define PREVIEWDIALOG_H

#include <tqdialog.h>
#include <kabc/addressee.h>

class Definition;
class KComboBox;
class KIntNumInput;
class KLineEdit;
class KPushButton;
class TQIODevice;
class TQLabel;
class TQWidget;
class PreviewDialog : public TQDialog  {
    Q_OBJECT
  TQ_OBJECT
    public: 
        PreviewDialog( TQIODevice* device, Definition* d, TQString filename, TQWidget *parent=0, const char *name=0);
        ~PreviewDialog();

    private slots:
        void updatechanges();
        void customerNameChanged( int index );
        void customerIdChanged( int index );
        void setupSql();
        void selectAddress();

    private:
        TQLabel* preview;
        
        KLineEdit* articleId;
        KLineEdit* groupName;
        KLineEdit* serialStart;
        KLineEdit* lineAddr;

        KIntNumInput* spinIndex;
        KIntNumInput* serialInc;
    
        KComboBox* customerName;
        KComboBox* customerId;
        
        KPushButton* buttonUpdate;
        KPushButton* buttonClose;
        KPushButton* buttonAddr;

        KABC::Addressee m_address;

        Definition* def;
        TQIODevice* file;

        TQString m_filename;

        static int customer_index;
        static int m_index;
        static TQString group;
        static TQString article;
};

#endif

==> kbarcode-trinity_14.1.0.orig.tar.xz: kbarcode-trinity-14.1.0/kbarcode/previewdialog.h <==
/***************************************************************************
                          previewdialog.h  -  description
                             -------------------
    begin                : Die Dez 10 2002
    copyright            : (C) 2002 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PREVIEWDIALOG_H
#define PREVIEWDIALOG_H

#include <tqdialog.h>
#include <tdeabc/addressee.h>

class Definition;
class KComboBox;
class KIntNumInput;
class KLineEdit;
class KPushButton;
class TQIODevice;
class TQLabel;
class TQWidget;
class PreviewDialog : public TQDialog  {
    Q_OBJECT
  
    public: 
        PreviewDialog( TQIODevice* device, Definition* d, TQString filename, TQWidget *parent=0, const char *name=0);
        ~PreviewDialog();

    private slots:
        void updatechanges();
        void customerNameChanged( int index );
        void customerIdChanged( int index );
        void setupSql();
        void selectAddress();

    private:
        TQLabel* preview;
        
        KLineEdit* articleId;
        KLineEdit* groupName;
        KLineEdit* serialStart;
        KLineEdit* lineAddr;

        KIntNumInput* spinIndex;
        KIntNumInput* serialInc;
    
        KComboBox* customerName;
        KComboBox* customerId;
        
        KPushButton* buttonUpdate;
        KPushButton* buttonClose;
        KPushButton* buttonAddr;

        TDEABC::Addressee m_address;

        Definition* def;
        TQIODevice* file;

        TQString m_filename;

        static int customer_index;
        static int m_index;
        static TQString group;
        static TQString article;
};

#endif
